@@ -2,6 +2,7 @@ from selenium import webdriver
 from webdriver_manager.chrome import ChromeDriverManager
 from selenium.webdriver.chrome.options import Options
 from selenium.webdriver.common.keys import Keys
+from selenium.webdriver.chrome.service import Service
 import time
 import pandas as pd
 from sqlalchemy import create_engine
@@ -21,8 +22,8 @@ class ScrapTrip():
     
     def __init__(self, chrome_options):
         
-
-        self.driver = webdriver.Chrome(options=chrome_options)
+        s = Service(ChromeDriverManager().install())
+        self.driver = webdriver.Chrome(service=s,options=chrome_options)
         
     def web_driver(self, URL: str)-> None:
         """get webdriver to pointing website
